# Generated by Django 3.2.13 on 2023-05-17 20:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('openlxp_xia', '0003_xisconfiguration_xis_api_key'),
    ]

    operations = [
        migrations.AlterField(
            model_name='xiaconfiguration',
            name='xss_api',
            field=models.CharField(help_text='Enter the XSS API', max_length=200),
        ),
    ]



from unittest.mock import patch

from django.core.exceptions import ValidationError
from django.test import TestCase, tag
from django.utils import timezone

from openlxp_xia.models import (MetadataFieldOverwrite, MetadataLedger,
                                SupplementalLedger, XIAConfiguration,
                                XISConfiguration)


@tag('unit')
class ModelTests(TestCase):

    def test_create_xia_configuration(self):
        """Test that creating a new XIA Configuration entry is successful
        with defaults """
        source_metadata_schema = 'test_file.json'
        xss_api = 'https://localhost'
        target_metadata_schema = 'test_file.json'

        xiaConfig = XIAConfiguration(
            source_metadata_schema=source_metadata_schema,
            xss_api=xss_api,
            target_metadata_schema=target_metadata_schema)

        self.assertEqual(xiaConfig.source_metadata_schema,
                         source_metadata_schema)
        self.assertEqual(xiaConfig.xss_api, xss_api)
        self.assertEqual(xiaConfig.target_metadata_schema,
                         target_metadata_schema)

    def test_create_two_xia_configuration(self):
        """Test that trying to create more than one XIS Configuration throws
        ValidationError """
        with patch("openlxp_xia.models.XIAConfiguration.field_overwrite"):
            with self.assertRaises(ValidationError):
                xiaConfig = \
                    XIAConfiguration(source_metadata_schema="example1.json",
                                     xss_api="https://localhost",
                                     target_metadata_schema="example1.json")
                xiaConfig2 = \
                    XIAConfiguration(source_metadata_schema="example2.json",
                                     xss_api="https://localhost",
                                     target_metadata_schema="example2.json")
                xiaConfig.save()
                xiaConfig2.save()

    def test_xia_field_overwrite(self):
        """Test that field_overwrite in an XIA Configuration generates
        MetadataFieldOverwrite objects """
        with patch("openlxp_xia.models.requests") as mock:
            target_schema = {"schema": {
                "start": {"test": {"use": "Required"}}}}
            transform_schema = {"schema_mapping": {
                "start": {"test": "start.test"}}}
            mock.get.return_value = mock
            mock.json.side_effect = [target_schema, transform_schema]
            xiaConfig = \
                XIAConfiguration(source_metadata_schema="example1.json",
                                 xss_api="https://localhost",
                                 target_metadata_schema="example1.json")
            xiaConfig.save()
            self.assertEqual(MetadataFieldOverwrite.objects.count(), 1)

    def test_create_xis_configuration(self):
        """Test that creating a new XIS Configuration entry is successful
        with defaults """
        xis_metadata_api_endpoint = 'http://localhost:8000/api/metadata/'
        xis_supplemental_api_endpoint = 'http://localhost:8000/api/supplement/'

        xisConfig = XISConfiguration(
            xis_metadata_api_endpoint=xis_metadata_api_endpoint,
            xis_supplemental_api_endpoint=xis_supplemental_api_endpoint)

        self.assertEqual(xisConfig.xis_supplemental_api_endpoint,
                         xis_supplemental_api_endpoint)
        self.assertEqual(xisConfig.xis_supplemental_api_endpoint,
                         xis_supplemental_api_endpoint)

    def test_create_two_xis_configuration(self):
        """Test that creating trying to create more than one XIS Configuration
        throws a ValidationError """
        xis_metadata_api_endpoint = 'http://localhost:8000/api/metadata/'
        xis_supplemental_api_endpoint = 'http://localhost:8000/api/supplement/'

        xisConfig = XISConfiguration(
            xis_metadata_api_endpoint=xis_metadata_api_endpoint,
            xis_supplemental_api_endpoint=xis_supplemental_api_endpoint)
        xisConfig2 = XISConfiguration(
            xis_metadata_api_endpoint=xis_metadata_api_endpoint,
            xis_supplemental_api_endpoint=xis_supplemental_api_endpoint)

        with self.assertRaises(ValidationError):
            xisConfig.save()
            xisConfig2.save()

    def test_metadata_ledger(self):
        """Test for a new Metadata_Ledger entry is successful with defaults"""
        metadata_record_inactivate_date = timezone.now()
        record_lifecycle_status = 'Active'
        source_metadata = ''
        source_metadata_extraction_date = ''
        source_metadata_hash = '74df499f177d0a7adb3e610302abc6a5'
        source_metadata_key = 'AGENT_test_key'
        source_metadata_key_hash = 'f6df40fbbf4a4c4091fbf64c9b6458e0'
        source_metadata_transform_date = timezone.now()
        source_metadata_validation_date = timezone.now()
        source_metadata_valid_status = 'Y'
        target_metadata = ''
        target_metadata_hash = '74df499f177d0a7adb3e610302abc6a5'
        target_metadata_key = 'AGENT_test_key'
        target_metadata_key_hash = '74df499f177d0a7adb3e610302abc6a5'
        target_metadata_transmit_date = timezone.now()
        target_meta_transmit_status = 'Ready'
        target_transmit_st_code = 200
        target_metadata_validation_date = timezone.now()
        target_metadata_validation_status = 'Y'

        metadataLedger = MetadataLedger(
            metadata_record_inactivation_date=metadata_record_inactivate_date,
            record_lifecycle_status=record_lifecycle_status,
            source_metadata=source_metadata,
            source_metadata_extraction_date=source_metadata_extraction_date,
            source_metadata_hash=source_metadata_hash,
            source_metadata_key=source_metadata_key,
            source_metadata_key_hash=source_metadata_key_hash,
            source_metadata_transformation_date=source_metadata_transform_date,
            source_metadata_validation_date=source_metadata_validation_date,
            source_metadata_validation_status=source_metadata_valid_status,
            target_metadata=target_metadata,
            target_metadata_hash=target_metadata_hash,
            target_metadata_key=target_metadata_key,
            target_metadata_key_hash=target_metadata_key_hash,
            target_metadata_transmission_date=target_metadata_transmit_date,
            target_metadata_transmission_status=target_meta_transmit_status,
            target_metadata_transmission_status_code=target_transmit_st_code,
            target_metadata_validation_date=target_metadata_validation_date,
            target_metadata_validation_status=target_metadata_validation_status
        )

        self.assertEqual(metadataLedger.metadata_record_inactivation_date,
                         metadata_record_inactivate_date)
        self.assertEqual(metadataLedger.record_lifecycle_status,
                         record_lifecycle_status)
        self.assertEqual(metadataLedger.source_metadata, source_metadata)
        self.assertEqual(metadataLedger.source_metadata_extraction_date,
                         source_metadata_extraction_date)
        self.assertEqual(metadataLedger.source_metadata_hash,
                         source_metadata_hash)
        self.assertEqual(metadataLedger.source_metadata_key,
                         source_metadata_key)
        self.assertEqual(metadataLedger.source_metadata_key_hash,
                         source_metadata_key_hash)
        self.assertEqual(metadataLedger.source_metadata_transformation_date,
                         source_metadata_transform_date)
        self.assertEqual(metadataLedger.source_metadata_validation_date,
                         source_metadata_validation_date)
        self.assertEqual(metadataLedger.source_metadata_validation_status,
                         source_metadata_valid_status)
        self.assertEqual(metadataLedger.target_metadata, target_metadata)
        self.assertEqual(metadataLedger.target_metadata_hash,
                         target_metadata_hash)
        self.assertEqual(metadataLedger.target_metadata_key,
                         target_metadata_key)
        self.assertEqual(metadataLedger.target_metadata_key_hash,
                         target_metadata_key_hash)
        self.assertEqual(metadataLedger.target_metadata_transmission_date,
                         target_metadata_transmit_date)
        self.assertEqual(metadataLedger.target_metadata_transmission_status,
                         target_meta_transmit_status)
        self.assertEqual(
            metadataLedger.target_metadata_transmission_status_code,
            target_transmit_st_code)
        self.assertEqual(metadataLedger.target_metadata_validation_date,
                         target_metadata_validation_date)
        self.assertEqual(metadataLedger.target_metadata_validation_status,
                         target_metadata_validation_status)

    def test_supplemental_ledger_ledger(self):
        """Test for a new SupplementalLedger entry is successful with
        defaults"""

        metadata_record_inactivate_date = timezone.now()
        record_lifecycle_status = 'Active'
        supplemental_metadata = ''
        supp_meta_extract_date = timezone.now()
        supplemental_metadata_hash = '74df499f177d0a7adb3e610302abc6a5'
        supplemental_metadata_key = 'AGENT_test_key'
        supplemental_metadata_key_hash = 'f6df40fbbf4a4c4091fbf64c9b6458e0'
        supp_meta_transform_date = timezone.now()
        supp_meta_transmit_date = timezone.now()
        supp_meta_transmit_stat = 'Ready'
        supp_meta_stat_cd = 200

        supplemental_ledger = SupplementalLedger(
            metadata_record_inactivation_date=metadata_record_inactivate_date,
            record_lifecycle_status=record_lifecycle_status,
            supplemental_metadata=supplemental_metadata,
            supplemental_metadata_extraction_date=supp_meta_extract_date,
            supplemental_metadata_hash=supplemental_metadata_hash,
            supplemental_metadata_key=supplemental_metadata_key,
            supplemental_metadata_key_hash=supplemental_metadata_key_hash,
            supplemental_metadata_transformation_date=supp_meta_transform_date,
            supplemental_metadata_transmission_date=supp_meta_transmit_date,
            supplemental_metadata_transmission_status=supp_meta_transmit_stat,
            supplemental_metadata_transmission_status_code=supp_meta_stat_cd

        )

        self.assertEqual(supplemental_ledger.metadata_record_inactivation_date,
                         metadata_record_inactivate_date)
        self.assertEqual(supplemental_ledger.record_lifecycle_status,
                         record_lifecycle_status)
        self.assertEqual(supplemental_ledger.supplemental_metadata,
                         supplemental_metadata)
        self.assertEqual(supplemental_ledger.
                         supplemental_metadata_extraction_date,
                         supp_meta_extract_date)
        self.assertEqual(supplemental_ledger.supplemental_metadata_hash,
                         supplemental_metadata_hash)
        self.assertEqual(supplemental_ledger.supplemental_metadata_key,
                         supplemental_metadata_key)
        self.assertEqual(supplemental_ledger.supplemental_metadata_key_hash,
                         supplemental_metadata_key_hash)
        self.assertEqual(supplemental_ledger.
                         supplemental_metadata_transformation_date,
                         supp_meta_transform_date)
        self.assertEqual(supplemental_ledger.
                         supplemental_metadata_transmission_date,
                         supp_meta_transmit_date)
        self.assertEqual(supplemental_ledger.
                         supplemental_metadata_transmission_status,
                         supp_meta_transmit_stat)
        self.assertEqual(supplemental_ledger.
                         supplemental_metadata_transmission_status_code,
                         supp_meta_stat_cd)

    def test_metadata_field_overwrite(self):
        """Test that creating a new Metadata Field Overwrite entry is
        successful with defaults """
        field_name = 'test_fields'
        field_type = 'int'
        field_value = '1234'
        overwrite = 'Yes'

        metadata_field_overwrite = MetadataFieldOverwrite(
            field_name=field_name,
            field_type=field_type,
            field_value=field_value,
            overwrite=overwrite)

        self.assertEqual(metadata_field_overwrite.field_name,
                         field_name)
        self.assertEqual(metadata_field_overwrite.field_type,
                         field_type)
        self.assertEqual(metadata_field_overwrite.field_value,
                         field_value)
        self.assertEqual(metadata_field_overwrite.overwrite,
                         overwrite)



# Generated by Django 3.2.18 on 2023-09-07 16:42

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('openlxp_xia', '0005_alter_xisconfiguration_xis_api_key'),
    ]

    operations = [
        migrations.AlterField(
            model_name='metadataledger',
            name='source_metadata',
            field=models.JSONField(blank=True, validators=[django.core.validators.RegexValidator(message='The Wrong Format Entered', regex='(?!(\\A( \\x09\\x0A\\x0D\\x20-\\x7E # ASCII | \\xC2-\\xDF # non-overlong 2-byte | \\xE0\\xA0-\\xBF # excluding overlongs | \\xE1-\\xEC\\xEE\\xEF{2} # straight 3-byte | \\xED\\x80-\\x9F # excluding surrogates | \\xF0\\x90-\\xBF{2} # planes 1-3 | \\xF1-\\xF3{3} # planes 4-15 | \\xF4\\x80-\\x8F{2} # plane 16 )*\\Z))')]),
        ),
        migrations.AlterField(
            model_name='supplementalledger',
            name='supplemental_metadata',
            field=models.JSONField(blank=True, validators=[django.core.validators.RegexValidator(message='The Wrong Format Entered', regex='(?!(\\A( \\x09\\x0A\\x0D\\x20-\\x7E # ASCII | \\xC2-\\xDF # non-overlong 2-byte | \\xE0\\xA0-\\xBF # excluding overlongs | \\xE1-\\xEC\\xEE\\xEF{2} # straight 3-byte | \\xED\\x80-\\x9F # excluding surrogates | \\xF0\\x90-\\xBF{2} # planes 1-3 | \\xF1-\\xF3{3} # planes 4-15 | \\xF4\\x80-\\x8F{2} # plane 16 )*\\Z))')]),
        ),
    ]



from unittest.mock import patch

from django.core.exceptions import ValidationError
from django.test import TestCase, tag

from openlxp_xia.models import XIAConfiguration


@tag('integration')
class ModelTests(TestCase):

    def test_create_two_xia_configuration(self):
        """Test that trying to create more than one XIA Configuration throws
        ValidationError """
        with patch('openlxp_xia.models.XIAConfiguration.field_overwrite'):
            with self.assertRaises(ValidationError):
                xiaConfig = XIAConfiguration(
                    publisher="XYZ",
                    source_metadata_schema="XYZ_source_validate_schema.json",
                    xss_api="https://localhost",
                    target_metadata_schema="p2881_schema.json")
                xiaConfig2 = XIAConfiguration(
                    publisher="ABC",
                    source_metadata_schema="ABC_source_validate_schema.json",
                    xss_api="https://localhost",
                    target_metadata_schema="p2881_schema.json")
                xiaConfig.save()
                xiaConfig2.save()



# Generated by Django 3.2.13 on 2022-06-28 13:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('openlxp_xia', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='xiaconfiguration',
            name='source_target_mapping',
        ),
        migrations.AddField(
            model_name='xiaconfiguration',
            name='xss_api',
            field=models.URLField(default='https://localhost', help_text='Enter the XSS API'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='metadatafieldoverwrite',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='xiaconfiguration',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='xiaconfiguration',
            name='source_metadata_schema',
            field=models.CharField(help_text='Enter the schema name/IRI', max_length=200),
        ),
        migrations.AlterField(
            model_name='xiaconfiguration',
            name='target_metadata_schema',
            field=models.CharField(help_text='Enter the target schema name/IRI to validate from.', max_length=200),
        ),
        migrations.AlterField(
            model_name='xisconfiguration',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
    ]



# Generated by Django 3.2.18 on 2025-02-19 17:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('openlxp_xia', '0007_auto_20250219_1719'),
    ]

    operations = [
        migrations.AlterField(
            model_name='xiaconfiguration',
            name='key_fields',
            field=models.TextField(default='["p2881_course_profile.Course_ID", "p2881_course_profile.CourseProviderName"]', help_text='Enter list of field names to create metadata key'),
        ),
    ]



import html
import bleach
import logging
from confusable_homoglyphs import categories, confusables

logger = logging.getLogger('dict_config_logger')


def bleach_data_to_json(rdata):
    """Recursive function to bleach/clean HTML tags from string
    data and return dictionary data.

    :param rdata: dictionary to clean.
    WARNING rdata will be edited
    :return: dict"""

    keysList = list(rdata.keys())
    for key in keysList:
        if isinstance(rdata[key], str):
            # if string, clean
            rdata[key] = bleach.clean(rdata[key], tags={}, strip=True)
            rdata[key] = html.unescape(rdata[key])
        if isinstance(rdata[key], dict):
            # if dict, enter dict
            rdata[key] = bleach_data_to_json(rdata[key])
    return rdata


def confusable_homoglyphs_check(data):
    """Checks for dangerous homoglyphs."""

    data_is_safe = True
    for key in data:

        # if string, Check homoglyph
        if isinstance(data[key], str) and bool(confusables.
                                               is_dangerous(data[key])):
            data_is_safe = False
            logger.info("Homoglyphs does not have the expected prefered alias")
            logger.error(categories.unique_aliases(data[key]))
        # if dict, enter dict
        if isinstance(data[key], dict):
            ret_val = confusable_homoglyphs_check(data[key])
            if not ret_val:
                data_is_safe = False
    return data_is_safe



# Generated by Django 3.2.18 on 2025-02-25 15:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('openlxp_xia', '0008_alter_xiaconfiguration_key_fields'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='xiaconfiguration',
            name='source_file',
        ),
        migrations.AlterField(
            model_name='xiaconfiguration',
            name='key_fields',
            field=models.TextField(blank=True, default='["p2881_course_profile.Course_ID", "p2881_course_profile.CourseProviderName"]', help_text='Enter list of field names to create metadata key', null=True),
        ),
        migrations.AlterField(
            model_name='xiaconfiguration',
            name='source_metadata_schema',
            field=models.CharField(blank=True, help_text='Enter the schema name/IRI', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='xiaconfiguration',
            name='target_metadata_schema',
            field=models.CharField(blank=True, help_text='Enter the target schema name/IRI to validate from.', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='xiaconfiguration',
            name='xss_api',
            field=models.CharField(blank=True, help_text='Enter the XSS API', max_length=200, null=True),
        ),
    ]



#!/Users/kjijo/Library/CloudStorage/OneDrive-Deloitte(O365D)/Github_Projects/ECC/openlxp-xia-1/app/enviroment_name/bin/python
from django.core import management

if __name__ == "__main__":
    management.execute_from_command_line()



import logging
import uuid

import requests
from django.core.validators import RegexValidator
from django.db import models
from django.forms import ValidationError
from django.urls import reverse
from django.utils import timezone
from model_utils.models import TimeStampedModel

from openlxp_xia.management.utils.model_help import (
    bleach_data_to_json, confusable_homoglyphs_check)

logger = logging.getLogger('dict_config_logger')


rcheck = (
    r'^('  # start at start
    r'[\x09\x0A\x0D\x20-\x7E]'  # ASCII
    r'|[\xC2-\xDF]'  # non-overlong 2-byte
    r'|[\xE0\xA0-\xBF]'  # excluding overlongs
    r'|[\xE1-\xEC\xEE\xEF]{2}'  # straight 3-byte
    r'|[\xED\x80-\x9F]'  # excluding surrogates
    r'|[\xF0\x90-\xBF]{2}'  # planes 1-3
    r'|[\xF1-\xF3]{3}'  # planes 4-15
    r'|[\xF4\x80-\x8F]{2}'  # plane 16
    r')*$')  # match all until end


class XIAConfiguration(TimeStampedModel):
    """Model for XIA Configuration """
    publisher = models.CharField(max_length=200,
                                 help_text='Enter the publisher name')
    xss_api = models.CharField(help_text='Enter the XSS API', max_length=200,
                               blank=True, null=True)
    source_metadata_schema = models.CharField(max_length=200,
                                              help_text='Enter the '
                                                        'schema name/IRI',
                                                        blank=True, null=True)
    target_metadata_schema = models.CharField(max_length=200,
                                              help_text='Enter the target '
                                                        'schema name/IRI to '
                                                        'validate from.',
                                                        blank=True, null=True)
    key_fields = models.TextField(default='["p2881_course_profile.Course_ID", "p2881_course_profile.CourseProviderName"]',
                                         help_text='Enter list of field names '
                                         'to create metadata key',
                                         blank=True, null=True)

    def get_absolute_url(self):
        """ URL for displaying individual model records."""
        return reverse('Configuration-detail', args=[str(self.id)])

    def __str__(self):
        """String for representing the Model object."""
        return f'{self.id}'

    def field_overwrite(self):
        # Deleting the corresponding existing value to overwrite
        MetadataFieldOverwrite.objects.all().delete()
        # get required columns list from schema files
        conf = self.xss_api
        # Read json file and store as a dictionary for processing
        request_path = conf
        if (self.target_metadata_schema.startswith('xss:')):
            request_path += 'schemas/?iri=' + self.target_metadata_schema
            conf += 'mappings/?targetIRI=' + self.target_metadata_schema
        else:
            request_path += 'schemas/?name=' + self.target_metadata_schema
            conf += 'mappings/?targetName=' + self.target_metadata_schema
        schema = requests.get(request_path, verify=False)
        target = schema.json()['schema']

        # Read json file and store as a dictionary for processing
        request_path = conf
        if (self.source_metadata_schema.startswith('xss:')):
            request_path += '&sourceIRI=' + self.source_metadata_schema
        else:
            request_path += '&sourceName=' + self.source_metadata_schema
        schema = requests.get(request_path, verify=False)
        mapping = schema.json()['schema_mapping']

        # saving required column values to be overwritten
        for section in target:
            for key, val in target[section].items():
                if "use" in val:
                    if val["use"] == 'Required':
                        if section in mapping and key in mapping[section]:
                            metadata_field_overwrite = MetadataFieldOverwrite()
                            metadata_field_overwrite.field_name = \
                                mapping[section][key]
                            # assigning default value for datatype field
                            # for metadata
                            metadata_field_overwrite.field_type = "str"
                            # assigning datatype field from schema
                            if "data_type" in val:
                                metadata_field_overwrite. \
                                    field_type = val["data_type"]
                            # logging if datatype for field not present in
                            # schema
                            else:
                                logger.warning("Datatype for required value " +
                                               section + "." + key +
                                               " not found in schema mapping")
                            metadata_field_overwrite.save()
                        # logging is mapping for metadata not present in schema
                        else:
                            logger.error("Mapping for required value " +
                                         section + "." + key +
                                         " not found in schema mapping")

    def save(self, *args, **kwargs):
        # Retrieve list of field required to be overwritten
        self.field_overwrite()
        if not self.pk and XIAConfiguration.objects.exists():
            raise ValidationError('There can be only one XIAConfiguration '
                                  'instance')
        return super(XIAConfiguration, self).save(*args, **kwargs)

    def delete(self, *args, **kwargs):
        # Deleting the corresponding existing value to overwrite
        metadata_fields = MetadataFieldOverwrite.objects.all()
        metadata_fields.delete()
        return super(XIAConfiguration, self).delete(*args, **kwargs)


class XISConfiguration(TimeStampedModel):
    """Model for XIS Configuration """

    xis_metadata_api_endpoint = models.CharField(
        help_text='Enter the XIS Metadata Ledger API endpoint',
        max_length=200
    )

    xis_supplemental_api_endpoint = models.CharField(
        help_text='Enter the XIS Supplemental Ledger API endpoint',
        max_length=200
    )

    xis_api_key = models.CharField(
        help_text="Enter the XIS API Key",
        max_length=128
    )

    def save(self, *args, **kwargs):
        if not self.pk and XISConfiguration.objects.exists():
            raise ValidationError('There can be only one XISConfiguration '
                                  'instance')
        return super(XISConfiguration, self).save(*args, **kwargs)


class MetadataLedger(TimeStampedModel):
    """Model for MetadataLedger """

    METADATA_VALIDATION_CHOICES = [('Y', 'Yes'), ('N', 'No')]
    RECORD_ACTIVATION_STATUS_CHOICES = [('Active', 'A'), ('Inactive', 'I')]
    RECORD_TRANSMISSION_STATUS_CHOICES = [('Successful', 'S'), ('Failed', 'F'),
                                          ('Pending', 'P'), ('Ready', 'R')]

    metadata_record_inactivation_date = models.DateTimeField(blank=True,
                                                             null=True)
    metadata_record_uuid = models.UUIDField(primary_key=True,
                                            default=uuid.uuid4, editable=False)
    record_lifecycle_status = models.CharField(
        max_length=10, blank=True, choices=RECORD_ACTIVATION_STATUS_CHOICES)
    source_metadata = models.JSONField(blank=True,
                                       validators=[RegexValidator(regex=rcheck,
                                                                  message="The"
                                                                  " Wrong "
                                                                  "Format "
                                                                  "Entered")])
    source_metadata_extraction_date = models.DateTimeField(auto_now_add=True)
    source_metadata_hash = models.CharField(max_length=200)
    source_metadata_key = models.TextField()
    source_metadata_key_hash = models.CharField(max_length=200)
    source_metadata_transformation_date = models.DateTimeField(blank=True,
                                                               null=True)
    source_metadata_validation_date = models.DateTimeField(blank=True,
                                                           null=True)
    source_metadata_validation_status = models.CharField(
        max_length=10, blank=True, choices=METADATA_VALIDATION_CHOICES)
    target_metadata = models.JSONField(default=dict)
    target_metadata_hash = models.CharField(max_length=200)
    target_metadata_key = models.TextField()
    target_metadata_key_hash = models.CharField(max_length=200)
    target_metadata_transmission_date = models.DateTimeField(blank=True,
                                                             null=True)
    target_metadata_transmission_status = models.CharField(
        max_length=10, blank=True, default='Ready',
        choices=RECORD_TRANSMISSION_STATUS_CHOICES)
    target_metadata_transmission_status_code = models.IntegerField(blank=True,
                                                                   null=True)
    target_metadata_validation_date = models.DateTimeField(blank=True,
                                                           null=True)
    target_metadata_validation_status = models.CharField(
        max_length=10, blank=True, choices=METADATA_VALIDATION_CHOICES)

    def save(self, *args, **kwargs):
        source_data = self.source_metadata
        # Checking for confusable hologlyphs
        data_checked = confusable_homoglyphs_check(source_data)
        if not data_checked:
            # If data check failed setting metadata to inactive
            self.record_lifecycle_status = "Inactive"
            self.metadata_record_inactivation_date = timezone.now()
        # cleaning metadata using bleach
        self.source_metadata = bleach_data_to_json(source_data)
        return super(MetadataLedger, self).save(*args, **kwargs)


class SupplementalLedger(TimeStampedModel):
    """Model for Supplemental Metadata """

    RECORD_ACTIVATION_STATUS_CHOICES = [('Active', 'A'), ('Inactive', 'I')]
    RECORD_TRANSMISSION_STATUS_CHOICES = [('Successful', 'S'), ('Failed', 'F'),
                                          ('Pending', 'P'), ('Ready', 'R')]

    metadata_record_inactivation_date = models.DateTimeField(blank=True,
                                                             null=True)
    metadata_record_uuid = models.UUIDField(primary_key=True,
                                            default=uuid.uuid4, editable=False)
    record_lifecycle_status = models.CharField(
        max_length=10, blank=True, choices=RECORD_ACTIVATION_STATUS_CHOICES)
    supplemental_metadata = models.JSONField(blank=True,
                                             validators=[RegexValidator
                                                         (regex=rcheck,
                                                          message="The"
                                                                  " Wrong "
                                                                  "Format "
                                                                  "Entered")])
    supplemental_metadata_extraction_date = models.DateTimeField(
        auto_now_add=True)
    supplemental_metadata_hash = models.CharField(max_length=200)
    supplemental_metadata_key = models.TextField()
    supplemental_metadata_key_hash = models.CharField(max_length=200)
    supplemental_metadata_transformation_date = models.DateTimeField(
        blank=True, null=True)
    supplemental_metadata_validation_date = models.DateTimeField(
        blank=True, null=True)
    supplemental_metadata_transmission_date = models.DateTimeField(
        blank=True, null=True)
    supplemental_metadata_transmission_status = models.CharField(
        max_length=10, blank=True, default='Ready',
        choices=RECORD_TRANSMISSION_STATUS_CHOICES)
    supplemental_metadata_transmission_status_code = models.IntegerField(
        blank=True, null=True)

    def save(self, *args, **kwargs):
        source_data = self.supplemental_metadata
        # Checking for confusable hologlyphs
        data_checked = confusable_homoglyphs_check(source_data)
        if not data_checked:
            # If data check failed setting metadata to inactive
            self.record_lifecycle_status = "Inactive"
            self.metadata_record_inactivation_date = timezone.now()
        # cleaning metadata using bleach
        self.source_metadata = bleach_data_to_json(source_data)
        return super(SupplementalLedger, self).save(*args, **kwargs)


class MetadataFieldOverwrite(TimeStampedModel):
    """Model for taking list of fields name and it's values for overwriting
    field values in Source metadata"""

    DATATYPE_CHOICES = (
        ('datetime', 'DATETIME'),
        ('int', 'INTEGER'),
        ('str', 'CHARACTER'),
        ('bool', 'BOOLEAN'),
    )

    field_name = models.CharField(max_length=200)
    field_type = models.CharField(max_length=200, choices=DATATYPE_CHOICES,
                                  null=True)
    field_value = models.CharField(max_length=200, null=True)
    overwrite = models.BooleanField(default=False)

    def __str__(self):
        """String for representing the Model object."""
        return f'{self.id}'

    def save(self, *args, **kwargs):
        return super(MetadataFieldOverwrite, self).save(*args, **kwargs)



# Generated by Django 3.2.13 on 2023-07-14 16:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('openlxp_xia', '0004_alter_xiaconfiguration_xss_api'),
    ]

    operations = [
        migrations.AlterField(
            model_name='xisconfiguration',
            name='xis_api_key',
            field=models.CharField(help_text='Enter the XIS API Key', max_length=128),
        ),
    ]



# Generated by Django 3.2.18 on 2025-02-19 17:19

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('openlxp_xia', '0006_auto_20230907_1642'),
    ]

    operations = [
        migrations.AddField(
            model_name='xiaconfiguration',
            name='key_fields',
            field=models.TextField(default="['p2881_course_profile.Course_ID', 'p2881_course_profile.CourseProviderName']", help_text='Enter list of field names to create metadata key'),
        ),
        migrations.AlterField(
            model_name='metadataledger',
            name='source_metadata',
            field=models.JSONField(blank=True, validators=[django.core.validators.RegexValidator(message='The Wrong Format Entered', regex='^([\\x09\\x0A\\x0D\\x20-\\x7E]|[\\xC2-\\xDF]|[\\xE0\\xA0-\\xBF]|[\\xE1-\\xEC\\xEE\\xEF]{2}|[\\xED\\x80-\\x9F]|[\\xF0\\x90-\\xBF]{2}|[\\xF1-\\xF3]{3}|[\\xF4\\x80-\\x8F]{2})*$')]),
        ),
        migrations.AlterField(
            model_name='supplementalledger',
            name='supplemental_metadata',
            field=models.JSONField(blank=True, validators=[django.core.validators.RegexValidator(message='The Wrong Format Entered', regex='^([\\x09\\x0A\\x0D\\x20-\\x7E]|[\\xC2-\\xDF]|[\\xE0\\xA0-\\xBF]|[\\xE1-\\xEC\\xEE\\xEF]{2}|[\\xED\\x80-\\x9F]|[\\xF0\\x90-\\xBF]{2}|[\\xF1-\\xF3]{3}|[\\xF4\\x80-\\x8F]{2})*$')]),
        ),
    ]



# Generated by Django 3.2.13 on 2023-05-17 13:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('openlxp_xia', '0002_use_xss'),
    ]

    operations = [
        migrations.AddField(
            model_name='xisconfiguration',
            name='xis_api_key',
            field=models.CharField(default='INVALID KEY', help_text='Enter the XIS API Key', max_length=40),
            preserve_default=False,
        ),
    ]



"""
Django settings for openlxp_xia_project project.

Generated by 'django-admin startproject' using Django 3.2.3.

For more information on this file, see
https://docs.djangoproject.com/en/3.2/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/3.2/ref/settings/
"""

import mimetypes
import os
import sys
from pathlib import Path

from dotenv import load_dotenv

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent

load_dotenv()


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/3.2/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = os.environ.get('SECRET_KEY_VAL')
# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

mimetypes.add_type("text/css", ".css", True)

ALLOWED_HOSTS = ['*']


# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'openlxp_xia',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'openlxp_xia_project.urls'
EMAIL_BACKEND = 'django_ses.SESBackend'
TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'openlxp_xia_project.wsgi.application'


# Database
# https://docs.djangoproject.com/en/3.2/ref/settings/#databases
#
DATABASES = {
    'default': {
        'ENGINE': 'mysql.connector.django',
        'NAME': os.environ.get('DB_NAME'),
        'USER': os.environ.get('DB_USER'),
        'PASSWORD': os.environ.get('DB_PASSWORD'),
        'HOST': os.environ.get('DB_HOST'),
        'PORT': 3306,
    }
}

if 'test' in sys.argv:
    DATABASES['default'] = {'ENGINE': 'django.db.backends.sqlite3'}

# Password validation
# https://docs.djangoproject.com/en/3.2/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation'
                '.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation'
                '.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation'
                '.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation'
                '.NumericPasswordValidator',
    },
]


# Internationalization
# https://docs.djangoproject.com/en/3.2/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/3.2/howto/static-files/

STATIC_URL = '/static/'
STATIC_ROOT = os.path.join(BASE_DIR, 'static')

LOG_PATH = os.environ.get('LOG_PATH')
LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,

    'loggers': {
        'dict_config_logger': {
            'handlers': ['console',],
            'level': 'INFO',
            'propagate': True,
        },
    },

    'handlers': {
        'console': {
            'class': 'logging.StreamHandler',
            'stream': sys.stdout,
            'formatter': 'simpleRe',
        },
        # 'file_logs': {
        #     'level': 'WARNING',
        #     'class': 'logging.FileHandler',
        #     'filename': LOG_PATH,
        #     'formatter': 'simpleRe',
        # },

    },

    'formatters': {
        'simpleRe': {
            'format': '{levelname} {asctime} {module} {message}',
            'style': '{',
        }
    }
}

CORS_ORIGIN_ALLOW_ALL = True

MEDIA_URL = '/media/'
MEDIA_ROOT = os.path.join(BASE_DIR, 'media')



import datetime
import hashlib
import json
import logging
import pandas as pd
from distutils.util import strtobool

from dateutil.parser import parse

from openlxp_xia.models import XIAConfiguration

logger = logging.getLogger('dict_config_logger')


def get_publisher_detail():
    """Retrieve publisher from XIA configuration """
    logger.debug("Retrieve publisher from XIA configuration")
    xia_data = XIAConfiguration.objects.first()
    publisher = xia_data.publisher
    return publisher


def get_key_dict(key_value, key_value_hash):
    """Creating key dictionary with all corresponding key values"""
    key = {'key_value': key_value, 'key_value_hash': key_value_hash}
    return key


def get_target_metadata_key_value(data_dict):
    """Function to create key value for target metadata """

    xia_data = XIAConfiguration.objects.first()
    target_key_fields = xia_data.key_fields

    key_fields = json.loads(target_key_fields)

    field_values = []
    data_df = pd.json_normalize(data_dict)

    for field in key_fields:
        try:
            value = data_df.at[0, field]
            field_values.append(value)
        except KeyError as e:
            logger.error(e)
            logger.info('Field name ' + field + ' is missing for '
                        'key creation')
            # field_values=[]
            # break

    # field = {
    #     "p2881_course_profile": [
    #         "Course_ID",
    #         "CourseProviderName"
    #     ]
    # }

    # field_values = []

    # for item_section in field:
    #     for item_name in field[item_section]:
    #         if not data_dict[item_section].get(item_name):
    #             logger.info('Field name ' + item_name + ' is missing for '
    #                                                     'key creation')
    #         field_values.append(data_dict[item_section].get(item_name))
    key_value=str()
    key_value_hash=str()
    if field_values:
    
        # Key value creation for source metadata
        key_value = '_'.join(field_values)

        # Key value hash creation for source metadata
        key_value_hash = hashlib.sha512(key_value.encode('utf-8')).hexdigest()

        # Key dictionary creation for source metadata
    key = get_key_dict(key_value, key_value_hash)
    return key


def required_recommended_logs(id_num, category, field):
    """logs the missing required and recommended """

    # Logs the missing required columns
    if category == 'Required':
        logger.error(
            "Record " + str(
                id_num) + " does not have all " + category +
            " fields."
            + field + " field is empty")

    # Logs the missing recommended columns
    if category == 'Recommended':
        logger.warning(
            "Record " + str(
                id_num) + " does not have all " + category +
            " fields."
            + field + " field is empty")

    # Logs the inaccurate datatype columns
    if category == 'datatype':
        logger.warning(
            "Record " + str(
                id_num) + " does not have the expected " + category +
            " for the field " + field)


def is_date(string, fuzzy=False):
    """
    Return whether the string can be interpreted as a date.

    :param string: str, string to check for date
    :param fuzzy: bool, ignore unknown tokens in string if True
    """
    if isinstance(string, str):
        try:
            parse(string, fuzzy=fuzzy)
            return True

        except ValueError:
            return False
    else:
        return False


def dict_flatten(data_dict, required_column_list):
    """Function to flatten/normalize  data dictionary"""

    # assign flattened json object to variable
    flatten_dict = {}

    # Check every key elements value in data
    for element in data_dict:
        # If Json Field value is a Nested Json
        if isinstance(data_dict[element], dict):
            flatten_dict_object(data_dict[element],
                                element, flatten_dict, required_column_list)
        # If Json Field value is a list
        elif isinstance(data_dict[element], list):
            flatten_list_object(data_dict[element],
                                element, flatten_dict, required_column_list)
        # If Json Field value is a string
        else:
            update_flattened_object(data_dict[element],
                                    element, flatten_dict)

    # Return the flattened json object
    return flatten_dict


def flatten_list_object(list_obj, prefix, flatten_dict, required_column_list):
    """function to flatten list object"""
    required_prefix_list = []
    for i in range(len(list_obj)):
        #  storing initial flatten_dict for resetting values
        if not i:
            flatten_dict_temp = flatten_dict
        # resetting flatten_dict to initial value
        else:
            flatten_dict = flatten_dict_temp

        if isinstance(list_obj[i], list):
            flatten_list_object(list_obj[i], prefix, flatten_dict,
                                required_column_list)

        elif isinstance(list_obj[i], dict):
            flatten_dict_object(list_obj[i], prefix, flatten_dict,
                                required_column_list)

        else:
            update_flattened_object(list_obj[i], prefix, flatten_dict)

        # looping through required column names
        for required_prefix in required_column_list:
            # finding matching value along with index
            try:
                required_prefix.index(prefix)
            except ValueError:
                continue
            else:
                if required_prefix.index(prefix) == 0:
                    required_prefix_list.append(required_prefix)
        #  setting up flag for checking validation
        passed = True

        # looping through items in required columns with matching prefix
        for item_to_check in required_prefix_list:
            #  flag if value not found
            if item_to_check in flatten_dict:
                if not flatten_dict[item_to_check]:
                    passed = False
            else:
                passed = False

        # if all required values are skip other object in list
        if passed:
            break


def flatten_dict_object(dict_obj, prefix, flatten_dict, required_column_list):
    """function to flatten dictionary object"""
    for element in dict_obj:
        if isinstance(dict_obj[element], dict):
            flatten_dict_object(dict_obj[element], prefix + "." +
                                element, flatten_dict, required_column_list)

        elif isinstance(dict_obj[element], list):
            flatten_list_object(dict_obj[element], prefix + "." +
                                element, flatten_dict, required_column_list)

        else:
            update_flattened_object(dict_obj[element], prefix + "." +
                                    element, flatten_dict)


def update_flattened_object(str_obj, prefix, flatten_dict):
    """function to update flattened object to dict variable"""

    flatten_dict.update({prefix: str_obj})


def convert_date_to_isoformat(date):
    """function to convert date to ISO format"""
    if isinstance(date, datetime.datetime):
        date = date.isoformat()
    return date


def type_cast_overwritten_values(field_type, field_value):
    """function to check type of overwritten value and convert it into
    required format"""
    value = field_value
    if field_value:
        if field_type == "int":
            try:
                value = int(field_value)
            except ValueError:
                logger.error("Field Value " + field_value +
                             " and Field Data type " + field_type +
                             " is not valid")
            except TypeError:
                logger.error("Field Value " + field_value +
                             " and Field Data type " + field_type +
                             " do not match")

        if field_type == "bool":
            try:
                value = strtobool(field_value)
            except ValueError:
                logger.error("Field Value " + field_value +
                             " and Field Data type " + field_type +
                             " is not valid")
            except TypeError:
                logger.error("Field Value " + field_value +
                             " and Field Data type " + field_type +
                             " do not match")
        if field_type == "datetime":
            try:
                is_date(field_value)
            except ValueError:
                logger.error("Field Value " + field_value +
                             " and Field Data type " + field_type +
                             " is not valid")
            except TypeError:
                logger.error("Field Value " + field_value +
                             " and Field Data type " + field_type +
                             " do not match")
    else:
        return None

    return value


def traverse_dict(metadata, key_val):
    """Function to traverse through dict"""
    if key_val not in metadata:
        metadata[key_val] = {}
    return metadata[key_val]


def traverse_dict_with_key_list(check_key_dict, key_list):
    """Function to traverse through dict with a key list"""
    for key in key_list[:-1]:
        if key in check_key_dict:
            check_key_dict = check_key_dict[key]
        else:
            check_key_dict = None
            logger.error("Path to traverse dictionary is "
                         "incorrect/ does not exist")
            return check_key_dict
    return check_key_dict



import logging

import requests
from django.core.cache import cache

from openlxp_xia.management.utils.xia_internal import dict_flatten
from openlxp_xia.models import XIAConfiguration

logger = logging.getLogger('dict_config_logger')


def xss_get():
    """Function to get xss configuration value"""
    conf = XIAConfiguration.objects.first()
    return conf.xss_api


def read_json_data(source_schema_ref, target_schema_ref=None):
    """get schema from xss and ingest as dictionary values"""
    xss_host = xss_get()
    request_path = xss_host
    if (target_schema_ref is not None):
        # check cache for schema
        cached_schema = cache.get(
            source_schema_ref + 'map' + target_schema_ref)
        if cached_schema:
            return cached_schema
        if (target_schema_ref.startswith('xss:')):
            request_path += 'mappings/?targetIRI=' + target_schema_ref
        else:
            request_path += 'mappings/?targetName=' + target_schema_ref
        if (source_schema_ref.startswith('xss:')):
            request_path += '&sourceIRI=' + source_schema_ref
        else:
            request_path += '&sourceName=' + source_schema_ref
        schema = requests.get(request_path, verify=False)
        json_content = schema.json()['schema_mapping']
        cache.add(source_schema_ref + 'map' +
                  target_schema_ref, json_content, timeout=10)
    else:
        cached_schema = cache.get(source_schema_ref)
        if cached_schema:
            return cached_schema
        if (source_schema_ref.startswith('xss:')):
            request_path += 'schemas/?iri=' + source_schema_ref
        else:
            request_path += 'schemas/?name=' + source_schema_ref
        schema = requests.get(request_path, verify=False)
        json_content = schema.json()['schema']
        cache.add(source_schema_ref, json_content, timeout=10)
    return json_content


def get_source_validation_schema():
    """Retrieve source validation schema from XIA configuration """
    logger.info("Configuration of schemas and files for source")
    xia_data = XIAConfiguration.objects.first()
    source_validation_schema = xia_data.source_metadata_schema
    if not source_validation_schema:
        logger.warning("Source validation field name is empty!")
    logger.info("Reading schema for validation")
    # Read source validation schema as dictionary
    schema_data_dict = read_json_data(source_validation_schema)
    return schema_data_dict


def get_target_validation_schema():
    """Retrieve target validation schema from XIA configuration """
    logger.info("Configuration of schemas and files for target")
    xia_data = XIAConfiguration.objects.first()
    target_validation_schema = xia_data.target_metadata_schema
    if not target_validation_schema:
        logger.warning("Target validation field name is empty!")
    logger.info("Reading schema for validation")
    # Read source validation schema as dictionary
    schema_data_dict = read_json_data(target_validation_schema)
    return schema_data_dict


def get_required_fields_for_validation(schema_data_dict):
    """Creating list of fields which are Required & Recommended"""

    # Call function to flatten schema used for validation
    flattened_schema_dict = dict_flatten(schema_data_dict, [])

    # Declare list for required and recommended column names
    required_column_list = list()
    recommended_column_list = list()

    #  Adding values to required and recommended list based on schema
    for column, value in flattened_schema_dict.items():
        if value == "Required":
            if column.endswith(".use"):
                column = column[:-len(".use")]
            required_column_list.append(column)
        elif value == "Recommended":
            if column.endswith(".use"):
                column = column[:-len(".use")]
            recommended_column_list.append(column)

    # Returning required and recommended list for validation
    return required_column_list, recommended_column_list


def get_data_types_for_validation(schema_data_dict):
    """Creating list of fields with the expected datatype objects"""

    # Call function to flatten schema used for validation
    flattened_schema_dict = dict_flatten(schema_data_dict, [])

    # mapping from string to datatype objects
    datatype_to_object = {
        "int": int,
        "str": str,
        "bool": bool,
        "list": list,
        "dict": dict
    }
    expected_data_types = dict()

    #  updating dictionary with expected datatype values for fields in metadata
    for column, value in flattened_schema_dict.items():
        if column.endswith(".data_type"):
            key = column[:-len(".data_type")]
            if value in datatype_to_object:
                value = datatype_to_object[value]
            expected_data_types.update({key: value})

    # Returning required and recommended list for validation
    return expected_data_types


def get_target_metadata_for_transformation():
    """Retrieve target metadata schema from XIA configuration """
    logger.info("Configuration of schemas and files for transformation")
    xia_data = XIAConfiguration.objects.first()
    target_metadata_schema = xia_data.target_metadata_schema
    source_metadata_schema = xia_data.source_metadata_schema
    if not target_metadata_schema or not source_metadata_schema:
        logger.warning("Metadata schema field name is empty!")
    logger.info("Reading schema for transformation")
    # Read source transformation schema as dictionary
    target_mapping_dict = read_json_data(
        source_metadata_schema, target_metadata_schema)
    return target_mapping_dict
